// ======================================================================
//
// gl_init.h
// jeff grills
//
// copyright 1996 origin systems inc
//
// ======================================================================

#ifndef GL_INIT_H
#define GL_INIT_H

// ======================================================================

class ClipInfo;

#include "Camera.h"
#include "ConfigEngine.h"
#include "ConfigPlatform.h"

// ======================================================================

struct GL_init
{
	// routines
	void    *(*MemoryManager__alloc)(u_int size, const char *filename, int line, bool array);
	void     (*MemoryManager__free)(void *ptr, bool array);
	u_int8   (*MemoryManager__getGuardPattern)(void);
	u_int8   (*MemoryManager__getUserPattern)(void);
	u_int8   (*MemoryManager__getFreePattern)(void);
	void     (*Fatal)(const char *fmt, ...);
	void     (*Warning)(const char *fmt, ...);
	void     (*Message)(const char *fmt, ...);

	// profile.h
	int                    *Profile__indx;
	Profile::ProfileEntry  *Profile__entry;

	Camera::RenderStats    *cameraRenderStats;

	ConfigEngine::Data     *engineParmData;
	ConfigPlatform::Data   *platformParmData;

	// dprint.h
	void            (*doNotUseDPrintClear)(void);
	void            (*doNotUseDPrint)(const char *fmt, ...);
	bool             *doNotUseDPrintFlag;
	bool             *doNotUseDPrintPaused;
	bool             *doNotUseDPrintLogging;
	bool             *doNotUseDPrintExplicitLogging;

	// dflag.h
	bool             *doNotUseDFlag;

	// dkey.h
	int              *doNotUseDKeyContext;
	int16            *doNotUseDKeyPressed;
	int16            *doNotUseDKeyDown;
};

struct GL_input
{
	// screen dimensions
	int               width;
	int               height;
	int               depth;

	// pointer to pointer to clip info
	const ClipInfo  **clipInfo;

	// rasterizer major and minor numbers
	int               major;
	int               minor;

	// the window
	HWND              window;

	bool              mfc;
};

struct GL_output
{
	bool              useSuperDetailFlag;
	bool              lightingRGB;
	bool              translucency;
	bool              fog;
	bool              bilinearFiltering;
	bool              lensFlares;

	bool              warningOneMegVideoCard;
	bool              warningBackBufferInSystemRam;
	bool              warningBankSwitched;

	int               textureMemory;

	// movie color information
	u_int8            rMovieSizeShift;
	u_int8            rMoviePlaceShift;
	u_int8            gMovieSizeShift;
	u_int8            gMoviePlaceShift;
	u_int8            bMovieSizeShift;
	u_int8            bMoviePlaceShift;
};

// ======================================================================

#endif
